﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;
using System.Windows.Forms;
using GradientBoostedTrees;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;
using HeuristicLab.Problems.DataAnalysis;

namespace HeuristicLab.Algorithms.DataAnalysis.Views {
  [View("Gradient boosted trees model")]
  [Content(typeof(GradientBoostedTreesModel), true)]
  public partial class GradientBoostedTreesModelView : AsynchronousContentView {
    public new GradientBoostedTreesModel Content {
      get { return (GradientBoostedTreesModel)base.Content; }
      set {
        base.Content = value;
      }
    }

    public GradientBoostedTreesModelView()
      : base() {
      InitializeComponent();
      viewHost.ViewsLabelVisible = false;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        // clear
        viewHost.Content = null;
        listBox.Items.Clear();
      } else {
        PopulateModelsList();
      }
    }

    private void PopulateModelsList() {
      listBox.BeginUpdate();
      listBox.Items.Clear();
      listBox.Items.AddRange(Content.Models.ToArray());
      listBox.EndUpdate();
    }

    private void listBox_SelectedIndexChanged(object sender, System.EventArgs e) {
      var idx = listBox.SelectedIndex;
      viewHost.Content = null;
      if (idx < 0) return;
      viewHost.Content = (IRegressionModel)listBox.Items[idx];
    }
  }
}
